#! /bin/sh


# The following two are the ANSI sequences for start and end embolden
case $TERM in
vt*|ansi*|con*|xterm*|linux*|screen*)
  S=[1m
  E=[m
  ;;
*)
  S=
  E=
  ;;
esac

PW_DIR=`pwd`

if test x$UID != x; then
  TRUST="--with-trusted=0,2,$UID"
else
  TRUST="--with-trusted=0,2"
fi

echo; echo "${S}__ STARTING TEST EXTERNAL PROGRAM __${E}"; echo;
echo Working directory: $PW_DIR

MAKE=`which gmake | sed -e "s%\([a-z:]\) .*%\1%g"` 
if test x$MAKE = x; then
	MAKE="make -s"
elif test x$MAKE = xno; then
	MAKE="make -s"
else
	if test "x$MAKE" = "xwhich:"; then
		MAKE="make -s"
	else
		MAKE="gmake -s"
	fi
fi
echo MAKE is $MAKE
echo


testext0 ()
{
	#
	# standalone compilation
	#
	echo "${S}Building standalone agent${E}"; echo;
	#
	if test -r "Makefile"; then
		$MAKE distclean
	fi
	#
	./configure --quiet  --prefix=$PW_DIR --with-dataroot-prefix=$PW_DIR --with-config-file=$PW_DIR/testrc_1ext  
	#
	if test x$? = x0; then
		echo "configure completed, exit status 0"; echo;
		$MAKE  > /dev/null
		echo "$MAKE completed, exit status $?"; echo;
	else
		echo "ERROR: configure failed"; echo;
	fi

	# prepare the script
	#
	PINP=`which perl`
	echo "#! $PINP" > test_ext
	echo >> test_ext
	echo "open   (OUT, \">>$PW_DIR/test_ext.res\")  " >> test_ext
	echo "  or die (\"Can't open output file!\");   " >> test_ext
	echo "while (<>) {                              " >> test_ext
	echo " \$_ =~ s/\[EOF\]\n//;                    " >> test_ext
	echo " printf OUT \$_;                          " >> test_ext
	echo " }                                        " >> test_ext
	echo "\$now_string = gmtime;                    " >> test_ext
	echo "printf OUT \"\$now_string : EXTERN: OK\\n\"; " >> test_ext
	chmod +rx  $PW_DIR/test_ext

	# compute checksum and fix config file
	#
	cp testrc_1ext.in testrc_1ext
	CHKSUM=`./samhain -H $PW_DIR/test_ext |  awk '{ print $2$3$4$5$6$7}'`
	echo "OpenCommand=$PW_DIR/test_ext" >> testrc_1ext
	echo "SetType=log"                  >> testrc_1ext
	echo "SetChecksum=$CHKSUM"          >> testrc_1ext
	echo "SetFilterOr=ALERT"             >> testrc_1ext

	rm -f $PW_DIR/test_ext.res
	./samhain 
	
	# The shell is too fast for Perl ...
 	sleep 1
	echo; 
	echo "${S}Logged by external perl script (filtered: ALERT only):${E}"; 
	echo;
	cat $PW_DIR/test_ext.res
	echo;
	
}



	testext0


echo; echo "${S}__ END TEST EXTERNAL PROGRAM __${E}"; echo;

exit

